@@ -12,7 +12,7 @@ use URI::Escape;
 
 use vars qw( $VERSION );
 
-$VERSION = '0.38';
+$VERSION = '0.39';
 
 =head1 NAME
 
@@ -184,7 +184,7 @@ sub display_node {
     # We've undef'ed $version above if this is the current version.
     $tt_vars{current} = 1 unless $version;
 
-    if ($id && $id eq "RecentChanges") {
+    if ($id eq "RecentChanges") {
         my $minor_edits = $self->get_cookie( "show_minor_edits_in_rc" );
         my %criteria = ( days => 7 );
         $criteria{metadata_was} = { edit_type => "Normal edit" }
@@ -480,6 +480,101 @@ sub list_all_versions {
     print $output;
 }
 
+=item B<commit_node>
+
+  $guide->commit_node(
+                       id      => $node,
+                       cgi_obj => $q,
+                     );
+
+As with other methods, parameters C<return_tt_vars> and
+C<return_output> can be used to return these things instead of
+printing the output to STDOUT.
+
+=cut
+
+sub commit_node {
+    my ($self, %args) = @_;
+    my $node = $args{id};
+    my $q = $args{cgi_obj};
+    my $wiki = $self->wiki;
+    my $config = $self->config;
+
+    my $content  = $q->param("content");
+    $content =~ s/\r\n/\n/gs;
+    my $checksum = $q->param("checksum");
+
+    my %metadata = OpenGuides::Template->extract_metadata_vars(
+        wiki    => $wiki,
+        config  => $config,
+	cgi_obj => $q
+    );
+
+    $metadata{opening_hours_text} = $q->param("hours_text") || "";
+
+    # Check to make sure all the indexable nodes are created
+    foreach my $type (qw(Category Locale)) {
+        my $lctype = lc($type);
+        foreach my $index (@{$metadata{$lctype}}) {
+	    $index =~ s/(.*)/\u$1/;
+	    my $node = $type . " " . $index;
+	    # Uppercase the node name before checking for existence
+	    $node =~ s/ (\S+)/ \u$1/g;
+	    unless ( $wiki->node_exists($node) ) {
+	        my $category = $type eq "Category" ? "Category" : "Locales";
+		$wiki->write_node( $node,
+		                   "\@INDEX_LINK [[$node]]",
+				   undef,
+				   { username => "Auto Create",
+				     comment  => "Auto created $lctype stub page",
+				     category => $category
+				   }
+		);
+	    }
+	}
+    }
+	
+    foreach my $var ( qw( username comment edit_type ) ) {
+        $metadata{$var} = $q->param($var) || "";
+    }
+    $metadata{host} = $ENV{REMOTE_ADDR};
+
+    my $written = $wiki->write_node($node, $content, $checksum, \%metadata );
+
+    if ($written) {
+        print $self->redirect_to_node($node);
+    } else {
+        my %node_data = $wiki->retrieve_node($node);
+        my %tt_vars = ( checksum       => $node_data{checksum},
+                        new_content    => $content,
+                        stored_content => $node_data{content} );
+        foreach my $mdvar ( keys %metadata ) {
+            if ($mdvar eq "locales") {
+                $tt_vars{"stored_$mdvar"} = $node_data{metadata}{locale};
+                $tt_vars{"new_$mdvar"}    = $metadata{locale};
+            } elsif ($mdvar eq "categories") {
+                $tt_vars{"stored_$mdvar"} = $node_data{metadata}{category};
+                $tt_vars{"new_$mdvar"}    = $metadata{category};
+            } elsif ($mdvar eq "username" or $mdvar eq "comment"
+                      or $mdvar eq "edit_type" ) {
+                $tt_vars{$mdvar} = $metadata{$mdvar};
+            } else {
+                $tt_vars{"stored_$mdvar"} = $node_data{metadata}{$mdvar}[0];
+                $tt_vars{"new_$mdvar"}    = $metadata{$mdvar};
+            }
+        }
+        return %tt_vars if $args{return_tt_vars};
+        my $output = $self->process_template(
+                                              id       => $node,
+                                              template => "edit_conflict.tt",
+                                              tt_vars  => \%tt_vars,
+                                            );
+        return $output if $args{return_output};
+        print $output;
+    }
+}
+
+
 =item B<delete_node>
 
   $guide->delete_node(
